mailr5697 - /1.3/generic_fns/structure/main.py


Others Months | Index by Date | Thread Index
>>   [Date Prev] [Date Next] [Thread Prev] [Thread Next]

Header


Content

Posted by edward on April 14, 2008 - 17:37:
Author: bugman
Date: Mon Apr 14 17:31:59 2008
New Revision: 5697

URL: http://svn.gna.org/viewcvs/relax?rev=5697&view=rev
Log:
The element type is added to the SpinContainer in the load_spins() function.


Modified:
    1.3/generic_fns/structure/main.py

Modified: 1.3/generic_fns/structure/main.py
URL: 
http://svn.gna.org/viewcvs/relax/1.3/generic_fns/structure/main.py?rev=5697&r1=5696&r2=5697&view=diff
==============================================================================
--- 1.3/generic_fns/structure/main.py (original)
+++ 1.3/generic_fns/structure/main.py Mon Apr 14 17:31:59 2008
@@ -111,8 +111,9 @@
             # Print out when a spin is appended.
             write_line(sys.stdout, mol_name, res_num, res_name, atom_num, 
atom_name, mol_name_flag=True, res_num_flag=True, res_name_flag=True, 
spin_num_flag=True, spin_name_flag=True)
 
         # Add the position vector to the spin container.
         spin_cont.pos = pos
+        spin_cont.element = element
 
 
 def read_pdb(file=None, dir=None, model=None, parser='scientific', 
@@ -111,8 +111,9 @@
spin_num_flag=True, spin_name_flag=True)
 
-        # Add the position vector to the spin container.
+        # Add the position vector and element type to the spin container.
         spin_cont.pos = pos
fail=True, verbosity=1):




Related Messages


Powered by MHonArc, Updated Mon Apr 14 18:00:32 2008